import type { HttpClient } from '../network/HttpClient.js';
import type { UserProvidedConfig } from '../sdk/types.js';
import type { SearchQuery, Schema } from '../types/index.js';
import type { ApiResponse, RecordsApi } from './types.js';
import { createFetcher } from '../network/index.js';
import { Transaction } from '../sdk/transaction.js';
import { createApi } from './create-api.js';
export declare class RestAPI {
    api: ReturnType<typeof createApi>;
    fetcher: ReturnType<typeof createFetcher>;
    records: RecordsApi;
    constructor(token?: string, config?: UserProvidedConfig & {
        httpClient: HttpClient;
    });
    relations: {
        find: <S extends Schema = any>({ pagination, search, transaction }: {
            pagination?: Pick<SearchQuery, "limit" | "skip">;
            search?: SearchQuery<S>;
            transaction?: Transaction | string;
        }) => Promise<ApiResponse<import("../sdk/record.js").Relation[]>>;
    };
    properties: {
        delete: (id: string, transaction?: Transaction | string) => Promise<ApiResponse<import("../types/value.js").Property>>;
        find: <S extends Schema = any>(searchParams: SearchQuery<S>, transaction?: Transaction | string) => Promise<ApiResponse<import("../types/value.js").Property[]>>;
        findById: (id: string, transaction?: Transaction | string) => Promise<ApiResponse<import("../types/value.js").Property>>;
        values: (id: string, transaction?: Transaction | string) => Promise<ApiResponse<import("../types/value.js").Property & import("../types/value.js").PropertyValuesData>>;
    };
    labels: {
        find: <S extends Schema = any>(searchParams: SearchQuery<S>, transaction?: Transaction | string) => Promise<ApiResponse<Record<string, number>>>;
    };
    tx: {
        begin: (config?: Partial<{
            ttl: number;
        }>) => Promise<Transaction>;
        commit: (id: string) => Promise<ApiResponse<{
            message: string;
        }>>;
        get: (id: string) => Promise<Transaction>;
        rollback: (id: string) => Promise<ApiResponse<{
            message: string;
        }>>;
    };
}
